@@ -44,16 +44,28 @@ fn main() {
 }
 ```
 */
+#![feature(test)]
+
+#[cfg(feature = "bench")]
+extern crate test;
+#[cfg(feature = "bench")]
+mod bench;
+
 #[macro_use]
 extern crate lazy_static;
 
 macro_rules! regexp {
     ($($arg:tt)*) => {{
         let reg_str = format!($($arg)*);
-        let rule_str = String::from(reg_str).replace(
+
+        let mut rule_str = String::from(reg_str).replace(
             r"\p{CJK}",
             r"\p{Han}|\p{Hangul}|\p{Hanunoo}|\p{Katakana}|\p{Hiragana}|\p{Bopomofo}",
         );
+        rule_str = String::from(rule_str).replace(
+            r"\p{CJ}",
+            r"\p{Han}|\p{Katakana}|\p{Hiragana}|\p{Bopomofo}",
+        );
         // println!("{}", rule_str);
         let res = regex::Regex::new(&rule_str).unwrap();
         res
@@ -74,40 +86,19 @@ macro_rules! map {
 mod code;
 mod fullwidth;
 mod halfwidth;
+pub mod ignorer;
 mod strategery;
-pub mod types;
-
-mod csharp;
-mod css;
-mod dart;
-mod elixir;
-mod go;
-mod html;
-mod java;
-mod javascript;
-mod json;
-mod kotlin;
-mod markdown;
-mod objective_c;
-mod php;
-mod python;
-mod ruby;
-mod rust;
-mod scala;
-mod sql;
-mod strings;
-mod swift;
-mod yaml;
+use code::Results;
+pub use code::{format_for, get_file_extension, is_support_type, lint_for};
 
 extern crate wasm_bindgen;
 use wasm_bindgen::prelude::*;
 
-// extern crate wee_alloc;
-// #[global_allocator]
-// static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
+extern crate wee_alloc;
+#[global_allocator]
+static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
 
 use crate::strategery::Strategery;
-pub use code::{FormatResult, LintResult, Results};
 use regex::Regex;
 
 lazy_static! {
@@ -130,7 +121,7 @@ lazy_static! {
         // 10%中文
         Strategery::new(r"[0-9][%]", r"\p{CJK}", true, false),
         // SpecialSymbol
-        Strategery::new(r"\p{CJK}", r"[\|+*]", true, true),
+        Strategery::new(r"\p{CJK}", r"[\|+]", true, true),
         // @ after CJK, not not before, 你好 @某某
         Strategery::new(r"\p{CJK}", r"[@]", true, false),
         Strategery::new(r"\p{CJK}", r"[\[\(‘“]", true, false),
@@ -176,7 +167,6 @@ pub fn format(text: &str) -> String {
         out = rule.format(&out)
     }
 
-    // out = remove_full_date_spacing(&out);
     out = space_dash_with_hans(&out);
 
     out
@@ -202,134 +192,21 @@ pub fn format(text: &str) -> String {
 /// ```
 #[wasm_bindgen(js_name = "formatHTML")]
 pub fn format_html(html_str: &str) -> String {
-    html::format_html(html_str).to_string()
-}
-
-/// Lint a file content with filetype.
-///
-/// Example:
-///
-/// ```
-//  extern crate autocorrect;
-//
-/// let raw = r#"
-/// <article>
-///   <h1>这是 Heading 标题</h1>
-///   <div class="content">
-///     <p>你好 Rust 世界<strong>Bold 文本</strong></p>
-///     <p>这是第二行 p 标签</p>
-///   </div>
-/// </article>
-/// "#;
-/// autocorrect::lint_for(raw, "html");
-/// autocorrect::lint_for(raw, "index.html");
-/// ```
-pub fn lint_for(raw: &str, filename_or_ext: &str) -> code::LintResult {
-    let mut result = match types::match_filename(filename_or_ext) {
-        "html" => html::lint_html(raw),
-        "yaml" => yaml::lint_yaml(raw),
-        "sql" => sql::lint_sql(raw),
-        "rust" => rust::lint_rust(raw),
-        "ruby" => ruby::lint_ruby(raw),
-        "elixir" => elixir::lint_elixir(raw),
-        "go" => go::lint_go(raw),
-        "javascript" => javascript::lint_javascript(raw),
-        "css" => css::lint_css(raw),
-        "json" => json::lint_json(raw),
-        "python" => python::lint_python(raw),
-        "objective_c" => objective_c::lint_objective_c(raw),
-        "strings" => strings::lint_strings(raw),
-        "csharp" => csharp::lint_csharp(raw),
-        "swift" => swift::lint_swift(raw),
-        "java" => java::lint_java(raw),
-        "scala" => scala::lint_scala(raw),
-        "kotlin" => kotlin::lint_kotlin(raw),
-        "php" => php::lint_php(raw),
-        "dart" => dart::lint_dart(raw),
-        "markdown" => markdown::lint_markdown(raw),
-        "text" => markdown::lint_markdown(raw),
-        _ => LintResult::new(raw),
-    };
-
-    result.filepath = String::from(filename_or_ext);
-
-    return result;
-}
-
-/// Format a file content with filetype.
-///
-/// Example:
-///
-/// ```
-//  extern crate autocorrect;
-//
-/// let raw = r#"
-/// <article>
-///   <h1>这是 Heading 标题</h1>
-///   <div class="content">
-///     <p>你好 Rust 世界<strong>Bold 文本</strong></p>
-///     <p>这是第二行 p 标签</p>
-///   </div>
-/// </article>
-/// "#;
-/// autocorrect::format_for(raw, "html");
-/// autocorrect::format_for(raw, "index.html");
-/// ```
-pub fn format_for(raw: &str, filename_or_ext: &str) -> code::FormatResult {
-    let result = match types::match_filename(filename_or_ext) {
-        "html" => html::format_html(raw),
-        "yaml" => yaml::format_yaml(raw),
-        "sql" => sql::format_sql(raw),
-        "rust" => rust::format_rust(raw),
-        "ruby" => ruby::format_ruby(raw),
-        "elixir" => elixir::format_elixir(raw),
-        "go" => go::format_go(raw),
-        "javascript" => javascript::format_javascript(raw),
-        "css" => css::format_css(raw),
-        "json" => json::format_json(raw),
-        "python" => python::format_python(raw),
-        "objective_c" => objective_c::format_objective_c(raw),
-        "strings" => strings::format_strings(raw),
-        "csharp" => csharp::format_csharp(raw),
-        "swift" => swift::format_swift(raw),
-        "java" => java::format_java(raw),
-        "scala" => scala::format_scala(raw),
-        "kotlin" => kotlin::format_kotlin(raw),
-        "php" => php::format_php(raw),
-        "dart" => dart::format_dart(raw),
-        "markdown" => markdown::format_markdown(raw),
-        "text" => markdown::format_markdown(raw),
-        _ => FormatResult::new(raw),
-    };
-
-    return result;
+    code::format_html(html_str).to_string()
 }
 
 /// Format content with filetype, and return a json result.
 #[wasm_bindgen(js_name = "formatFor")]
 pub fn format_for_json_out(raw: &str, filename_or_ext: &str) -> wasm_bindgen::JsValue {
     let result = format_for(raw, filename_or_ext);
-    return wasm_bindgen::JsValue::from_serde(&result).unwrap();
+    wasm_bindgen::JsValue::from_serde(&result).unwrap()
 }
 
 /// Lint content with filetype, and return a json result.
 #[wasm_bindgen(js_name = "lintFor")]
 pub fn lint_for_json_out(raw: &str, filename_or_ext: &str) -> wasm_bindgen::JsValue {
     let result = lint_for(raw, filename_or_ext);
-    return wasm_bindgen::JsValue::from_serde(&result).unwrap();
-}
-
-// removeFullDateSpacing
-// 发布2013年3月10号公布 -> 发布2013年3月10号公布
-#[allow(dead_code)]
-fn remove_full_date_spacing(text: &str) -> String {
-    let mut out = String::from(text);
-    for ma in FULL_DATE_RE.find_iter(&text) {
-        let new_val = ma.as_str().replace(" ", "");
-        out = out.replace(ma.as_str(), &new_val);
-    }
-
-    return out;
+    wasm_bindgen::JsValue::from_serde(&result).unwrap()
 }
 
 fn space_dash_with_hans(text: &str) -> String {
@@ -339,7 +216,7 @@ fn space_dash_with_hans(text: &str) -> String {
     out = (&DASH_HANS_RE.replace_all(&out, "$1 $2 $3")).to_string();
     out = (&LEFT_QUOTE_RE.replace_all(&out, "$1")).to_string();
     out = (&RIGHT_QUOTE_RE.replace_all(&out, "$1")).to_string();
-    return out;
+    out
 }
 
 #[cfg(test)]
@@ -373,8 +250,10 @@ mod tests {
             "隔夜SHIBOR报1.5530%，上涨33.80%个基点。7天SHIBOR报2.3200%，上涨6.10个基点。3个月SHIBOR报2.8810%，下降1.80个" => "隔夜 SHIBOR 报 1.5530%，上涨 33.80% 个基点。7 天 SHIBOR 报 2.3200%，上涨 6.10 个基点。3 个月 SHIBOR 报 2.8810%，下降 1.80 个",
             "野村：重申吉利汽车(00175)“买入”评级 上调目标价至17.9港元" => "野村：重申吉利汽车 (00175)“买入” 评级 上调目标价至 17.9 港元",
             "小米集团-W调整目标价为13.5港币" => "小米集团-W 调整目标价为 13.5 港币",
-            "（路透社）-预计全年净亏损约1.3亿港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿港元 * 预期因出售汽车",
-            "（路透社）-预计全年净亏损约1.3亿\n\n港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿\n\n港元 * 预期因出售汽车"
+            "（路透社）-预计全年净亏损约1.3亿港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿港元*预期因出售汽车",
+            "（路透社）-预计全年净亏损约1.3亿\n\n港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿\n\n港元*预期因出售汽车",
+            "Cell或RefCell类型使用某种形式的*内部" => "Cell 或 RefCell 类型使用某种形式的*内部",
+            "Cell或RefCell类型使用某种形式的*内部可变性*" => "Cell 或 RefCell 类型使用某种形式的*内部可变性*"
         ];
 
         assert_cases(cases);
@@ -491,7 +370,7 @@ mod tests {
             "全世界已有数百家公司在生产环境中使用Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如Firefox、 Dropbox和Cloudflare都在使用Rust。" => "全世界已有数百家公司在生产环境中使用 Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如 Firefox、 Dropbox 和 Cloudflare 都在使用 Rust。",
             "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用Rust。許多耳熟能詳且受歡迎的軟體，諸如Firefox、Dropbox以及Cloudflare都在使用Rust。" => "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用 Rust。許多耳熟能詳且受歡迎的軟體，諸如 Firefox、Dropbox 以及 Cloudflare 都在使用 Rust。",
             "既に、世界中の数百という企業がRustを採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えばFirefox、DropboxやCloudflareも、Rustを採用しています。" => "既に、世界中の数百という企業が Rust を採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えば Firefox、Dropbox や Cloudflare も、Rust を採用しています。",
-            "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust를 사용하여 빠르고, 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust를 사용하고 있습니다." => "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust 를 사용하여 빠르고，크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare 와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust 를 사용하고 있습니다。"
+            "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust를 사용하여 빠르고, 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust를 사용하고 있습니다." => "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust 를 사용하여 빠르고, 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare 와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust 를 사용하고 있습니다."
         ];
 
         assert_cases(cases);
@@ -502,12 +381,12 @@ mod tests {
         let raw = "<p>Hello你好</p>";
         let result = lint_for(raw, "foo.bar.html");
         let expect_json = r#"{"filepath":"foo.bar.html","lines":[{"l":1,"c":4,"new":"Hello 你好","old":"Hello你好"}],"error":""}"#;
-        assert_eq!(false, result.has_error());
+        assert!(!result.has_error());
         assert_eq!(1, result.lines.len());
         assert_eq!(expect_json, result.to_json());
 
         let result1 = lint_for("const a = 'hello世界'", "js");
-        assert_eq!(false, result1.has_error());
+        assert!(!result1.has_error());
         assert_eq!(1, result1.lines.len());
     }
 
@@ -515,11 +394,11 @@ mod tests {
     fn it_format_for() {
         let raw = "<p>Hello你好</p>";
         let result = format_for(raw, "foo.bar.html");
-        assert_eq!(false, result.has_error());
+        assert!(!result.has_error());
         assert_eq!("<p>Hello 你好</p>", result.out);
 
         let result1 = format_for("const a = 'hello世界'", "js");
-        assert_eq!(false, result1.has_error());
+        assert!(!result1.has_error());
         assert_eq!("const a = 'hello 世界'", result1.out);
     }
 }
